<?php
/**
 * Get posts pagination
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_get_posts_pagination' ) )
{
    function ave_lite_get_posts_pagination($args = array())
    {
        global $wp_query;
        $output = '';
        $args = shortcode_atts(array(
            'wrap_class'         => '',
            'prev_text'          => esc_html__( '&laquo;', 'ave-lite' ),
            'next_text'          => esc_html__( '&raquo;', 'ave-lite' ),
            'prev_next'          => true,
            'q'                  => $wp_query,
            'before_page_number' => '',
            'after_page_number'  => '',
            'before_paginate'    => $args['wrap_class']? '<div class="pagination uk-pagination '. $args['wrap_class'] .'">':'<div class="pagination uk-pagination">',
            'after_paginate'     => '</div>'
        ), $args );

        $total = $args['q']->max_num_pages;

        if (get_query_var('paged') ) {
            $paged = get_query_var('paged');
        } elseif (get_query_var('page')) {
            $paged = get_query_var('page');
        } else {
            $paged = 1;
        }

        if ( $total > 1 ) {
            $output .= $args['before_paginate'];
            $output .= paginate_links( array(
                'prev_text'          => $args['prev_text'],
                'next_text'          => $args['next_text'],
                'prev_next'          => $args['prev_next'],
                'total'              => $total,
                'current'            => $paged,
                'before_page_number' => $args['before_page_number'],
                'after_page_number'  => $args['after_page_number']
            ) );
            $output .= $args['after_paginate'];
        }
        return $output;
    }
}


/**
 * get post date
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_get_post_time' ) ) {
    function ave_lite_get_post_time( $date_format=false, $post_id = false )
    {
        if ( $date_format == false ) {
            $date_format = get_option( 'date_format' );
        }
        if ( $post_id === false ) {
            $post_id = get_the_ID();
        }
        $time_string = '<time class="time published updated" datetime="%1$s">%2$s</time>';
        $time_string = sprintf( $time_string,
            get_the_date( DATE_W3C, $post_id ),
            get_the_date( $date_format, $post_id ),
            get_the_modified_date( DATE_W3C ),
            get_the_modified_date()
        );

        return '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';
    }
}


/**
 * Edit Link
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_edit_link' ) ) {
    function ave_lite_edit_link()
    {
        edit_post_link(
            sprintf(
            /* translators: %s: Name of current post */
                __('Edit<span class="screen-reader-text"> "%s"</span>', 'ave-lite'),
                get_the_title()
            ),
            '<span class="edit-link">',
            '</span>'
        );
    }
}


/**
 * Get Category List
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_get_categories_list' ) )
{
    function ave_lite_get_categories_list( $text=', ' )
    {
        $categories_list = get_the_category_list( $text );
        if ( $categories_list ) {
            return $categories_list;
        } else {
            return false;
        }
    }
}



/**
 * get post comments
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_get_post_comments' ) ) {
    function ave_lite_get_post_comments( $show_only_number=false )
    {
        $output = '';
        ob_start();
        if ( $show_only_number == true ) {
            comments_popup_link(
                esc_html__( '0', 'ave-lite' ),
                esc_html__( '1', 'ave-lite' ),
                esc_html__( '%', 'ave-lite' )
            );
        } else {
            comments_popup_link(
                esc_html__( '0 comment', 'ave-lite' ),
                esc_html__( '1 comment', 'ave-lite' ),
                esc_html__( '% comments', 'ave-lite' )
            );
        }
        $output .= ob_get_clean();
        return $output;
    }
}



/**
 * Get Comment List
 * @package WordPress
 * @subpackage AveTheme
 * @version 1.0.0
 */
if ( !function_exists( 'ave_lite_get_comments_list' ) )
{
    function ave_lite_get_comments_list( $comment, $args, $depth )
    {
        ?>
    <li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
        <article class="uk-comment uk-visible-toggle">
            <header class="uk-comment-header uk-position-relative">
                <div class="uk-grid-small uk-flex-middle" uk-grid>
                    <?php if ( get_option( 'show_avatars' ) == true ) : ?>
                        <div class="uk-width-auto comment-avatar">
                            <?php echo get_avatar( $comment, 96 ); ?>
                        </div>
                    <?php endif; ?>
                    <div class="uk-width-expand">
                        <h4 class="uk-comment-title uk-margin-remove">
                            <?php
                            printf(
                                '<cite class="fn comment-title">%1$s</cite>',
                                get_comment_author_link()
                            );
                            ?>
                        </h4>
                        <p class="uk-comment-meta uk-margin-remove-top">
                            <?php
                            printf(
                                '<time class="time comment-date" datetime="%1$s">%2$s</time>',
                                get_comment_time( 'c' ),
                                sprintf( esc_html__( '%1$s at %2$s', 'ave-lite' ),
                                    get_comment_date(),
                                    get_comment_time()
                                ) );
                            ?>
                        </p>
                    </div>
                </div>
                <div class="uk-position-top-right uk-position-small uk-hidden-hover">
                    <?php
                    comment_reply_link( wp_parse_args( $args, array(
                        'reply_text'   => esc_html__( 'Reply', 'ave-lite' ),
                        'before'       => '<span class="reply-link reply-link-comment">',
                        'after'        => '</span>',
                        'depth'        => $depth,
                        'max_depth'    => $args['max_depth']
                    ) ) );
                    edit_comment_link(
                        esc_html__( 'Edit', 'ave-lite' ),
                        '<span class="edit-link edit-link-comment">',
                        '</span>'
                    );
                    ?>
                </div>
            </header>
            <div class="uk-comment-body comment-content">
                <?php if ( $comment->comment_approved == '0' ) : ?>
                    <p class="comment-awaiting-moderation uk-alert uk-alert-danger">
                        <?php esc_html_e( 'Your comment is awaiting moderation.', 'ave-lite' ); ?>
                    </p>
                <?php endif; ?>
                <?php comment_text(); ?>
            </div>
        </article>
        <?php
    }
}